|CI| |docs|

pydoas: a python library for post-analysis and visualisation of DOAS fit result data
====================================================================================

pydoas is a Python library for reading, postprocessing and plotting of DOAS (Differential Optical Absorption Spectroscopy) fit results. 
It supports default import of the result file format of
`DOASIS <https://hci.iwr.uni-heidelberg.de/content/doasis-framework-design-doas>`_. 
Further import formats for fast data access can easily be defined by the user.

.. note::

  pydoas is not a library for performing DOAS spectrum analysis. An overview and assessment of existing DOAS
  retrieval codes can by found e.g. in `Peters et al., 2017 <https://amt.copernicus.org/articles/10/955/2017/amt-10-955-2017.html>`_

Documentation: https://pydoas.readthedocs.io/en/latest/

.. |CI| image:: https://github.com/jgliss/pydoas/actions/workflows/CI.yml/badge.svg
    :target: https://github.com/jgliss/pydoas/actions/

.. |docs| image:: https://readthedocs.org/projects/pydoas/badge/?version=latest
    :target: https://pydoas.readthedocs.io/en/latest/?badge=latest
